import bpy
from bpy.props import (IntProperty)

armature = bpy.data.objects['Armature_FK_IK']

##########################
####### Leg FK IK ########
bone_1_IK = armature.pose.bones["Mch_bone_IK.000"]
bone_1_FK = armature.pose.bones["Ctrl_bone_FK.000"]
bone_2_IK = armature.pose.bones["Mch_bone_IK.001"]
bone_2_FK = armature.pose.bones["Ctrl_bone_FK.001"]
bone_3_IK = armature.pose.bones["Mch_bone_IK.002"]
bone_3_FK = armature.pose.bones["Ctrl_bone_FK.002"]
bone_IK = armature.pose.bones["Ctrl_bone_IK"]
bone_FK = armature.pose.bones["Mch_bone_FK"]

##### FK IK functions #####
def FK2IK_Leg(self):
    bone_1_FK.matrix = bone_1_IK.matrix
    bone_2_FK.matrix = bone_2_IK.matrix
    bone_3_FK.matrix = bone_3_IK.matrix

def IK2FK_Leg(self):
    bone_IK.matrix = bone_FK.matrix
    bone_1_IK.matrix = bone_1_FK.matrix
    bone_2_IK.matrix = bone_2_FK.matrix
    bone_3_IK.matrix = bone_3_FK.matrix

#### Classes ####
class Operator_FK2IK_Leg(bpy.types.Operator):
    """Leg snaping FK to IK"""
    bl_idname = "object.operator_fk2ik_leg"
    bl_label = "Snap"

#    def execute(self, context):
#        # Bad solution with bpy.ops.wm.redraw_timer with a For loop!
#        for i in range(0, 9):
#            FK2IK_Leg(context)
#            bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
#        return {'FINISHED'}

    def execute(self, context):
        FK2IK_Leg(context)
        return {'FINISHED'}

class Operator_IK2FK_Leg(bpy.types.Operator):
    """Leg snaping IK to FK"""
    bl_idname = "object.operator_ik2fk_leg"
    bl_label = "Snap"

#    def execute(self, context):
#        # Bad solution with bpy.ops.wm.redraw_timer with a For loop!
#        for i in range(0, 18):
#            IK2FK_Leg(context)
#            bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
#        return {'FINISHED'}

    def execute(self, context):
        IK2FK_Leg(context)
        return {'FINISHED'}

class LayoutDemoPanel(bpy.types.Panel):
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Item'
    bl_label = "Snap"

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        ### Snaping Front leg IK / FK buttons
        layout.label(text="Leg:")
        row = layout.row()
        row.scale_y = 1.0
        row.label(text="FK to IK")
        row.operator("object.operator_fk2ik_leg")
        row = layout.row()
        row.scale_y = 1.0
        row.label(text="IK to FK")
        row.operator("object.operator_ik2fk_leg")

classes = (
#    Operator_Control,
    Operator_FK2IK_Leg,
    Operator_IK2FK_Leg,
    LayoutDemoPanel
    )

def register():
    for cls in classes:
        bpy.utils.register_class(cls)

def unregister():
    for cls in classes:
        bpy.utils.unregister_class(cls)

if __name__ == "__main__":
    register()